ValidationError

Enum ValidationError 

#[non_exhaustive]
pub enum ValidationError {
Show 22 variants SchemaVersion { found: u16, }, TooLarge, InputWidthOutOfRange { slot: usize, width: u16, }, NodeWidthOutOfRange { at: u32, width: u16, }, Arity { at: u32, expected: usize, found: usize, }, OperandOutOfRange { at: u32, operand: u32, }, NonCanonicalEdge { at: u32, operand: u32, }, OperandTyping { at: u32, reason: &'static str, }, OutputWidth { at: u32, reason: &'static str, }, ConstantBytes { at: u32, expected: usize, found: usize, }, InputSlotOutOfRange { at: u32, slot: u16, }, InputWidthMismatch { at: u32, declared: u16, input: u16, }, LookupKeyWidth { at: u32, expected: u16, found: u16, }, LookupBound { at: u32, reason: &'static str, }, OutputRefOutOfRange { which: &'static str, id: u32, }, OutputNotPredicate { which: &'static str, width: u16, }, RefusalCodeTooWide { width: u16, }, Limit(LimitViolation), CertificateMismatch, MalformedEncoding, NonCanonicalEncoding, Encoding,
}
Why a program failed validation. The validator fails closed on the FIRST fault; each variant names a malformed class its red fixtures prove it catches.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SchemaVersion

The program declares a schema version other than the frozen one.

Fields

found: u16

The declared version.



TooLarge

The node count is not u32-indexable.



InputWidthOutOfRange

A declared input lane width is outside 1 ..= MAX_WIDTH.

Fields

slot: usize

The input slot.

width: u16

The offending width.



NodeWidthOutOfRange

A node’s output width is outside 1 ..= MAX_WIDTH.

Fields

at: u32

The node index.

width: u16

The offending width.



Arity

A node’s fan-in does not match its op’s frozen arity.

Fields

at: u32

The node index.

expected: usize

The required arity.

found: usize

The arity found.



OperandOutOfRange

An operand references a node id outside the array.

Fields

at: u32

The node index.

operand: u32

The out-of-range operand id.



NonCanonicalEdge

An operand references the node itself or a later node.

Fields

at: u32

The node index.

operand: u32

The forward/self operand id.



OperandTyping

Operands that must share (or relate by) a width do not.

Fields

at: u32

The node index.

reason: &'static str

What the typing rule requires.



OutputWidth

A node’s declared output width disagrees with what its op produces.

Fields

at: u32

The node index.

reason: &'static str

What the rule requires.



ConstantBytes

A constant’s byte length does not match its declared width.

Fields

at: u32

The node index.

expected: usize

Required byte length (⌈width/8⌉).

found: usize

Byte length found.



InputSlotOutOfRange

An NodeOp::Input references a slot outside the input declaration.

Fields

at: u32

The node index.

slot: u16

The out-of-range slot.



InputWidthMismatch

An input node’s declared width disagrees with the declared input lane.

Fields

at: u32

The node index.

declared: u16

The node’s declared width.

input: u16

The input lane’s width.



LookupKeyWidth

A lookup’s key operand width disagrees with the table’s key width.

Fields

at: u32

The node index.

expected: u16

The table’s declared key width.

found: u16

The key operand’s width.



LookupBound

A lookup table is over-large or has a mis-sized entry.

Fields

at: u32

The node index.

reason: &'static str

What the bound rule requires.



OutputRefOutOfRange

A declared output references a node id outside the array.

Fields

which: &'static str

Which output ("admit", "refusal_code", "membrane").

id: u32

The out-of-range id.



OutputNotPredicate

A predicate output references a non-1-bit lane.

Fields

which: &'static str

Which output.

width: u16

The referenced lane’s width.



RefusalCodeTooWide

The refusal-code lane is wider than a u64.

Fields

width: u16

The lane width.



Limit(LimitViolation)

The program exceeds the structural limits.



CertificateMismatch

A re-derived certificate did not match the claimed one.



MalformedEncoding

The bytes did not decode to a program.



NonCanonicalEncoding

The bytes decoded but are not the program’s canonical encoding.



Encoding

Canonical re-encoding failed.